# Sanstyle

[![GitHub issues](https://img.shields.io/github/issues/xinetzone/sanstyle)](https://github.com/xinetzone/sanstyle/issues) [![GitHub forks](https://img.shields.io/github/forks/xinetzone/sanstyle)](https://github.com/xinetzone/sanstyle/network) [![GitHub stars](https://img.shields.io/github/stars/xinetzone/sanstyle)](https://github.com/xinetzone/sanstyle/stargazers) [![GitHub license](https://img.shields.io/github/license/xinetzone/sanstyle)](https://github.com/xinetzone/sanstyle/blob/main/LICENSE)  ![repo size](https://img.shields.io/github/repo-size/xinetzone/sanstyle.svg) [![contributors](https://img.shields.io/github/contributors/xinetzone/sanstyle.svg)](https://github.com/xinetzone/sanstyle/graphs/contributors) [![watcher](https://img.shields.io/github/watchers/xinetzone/sanstyle.svg)](https://github.com/xinetzone/sanstyle/watchers) ![](https://github.com/xinetzone/sanstyle/actions/workflows/python-publish.yml/badge.svg)

上善若水

被发布到 [Sanstyle · PyPI](https://pypi.org/project/sanstyle/)。 更多内容见 [xinetzone/governance](https://github.com/xinetzone/governance)。

- `sanstyle.html` 用于处理 HTML
- `sanstyle.github` 用于处理 GitHub